key property
key for saving preference
- You must set the
keyor it will throw. This is a safety check to prevent different instances overwriting each other save.
Implementation
final String key;
key for saving preference
key or it will throw. This is a safety check to prevent different instances overwriting each other save.final String key;